pub struct ExampleBuilder;Expand description
Generator that produces example values based on a Schema
Implementations
Sourceimpl ExampleBuilder
impl ExampleBuilder
Sourcepub fn from_schema(schema: &Schema) -> Value
pub fn from_schema(schema: &Schema) -> Value
Generates an example value based on the Schema
- Object: recursively generates examples for all fields
- Array: generates a single-element array
- Reference: returns null (the caller needs to resolve the reference)
- Primitive: generates a reasonable default value based on type/format
Sourcepub fn from_object(obj: &ObjectType) -> Value
pub fn from_object(obj: &ObjectType) -> Value
Generates an example object based on an object Schema
Sourcepub fn from_primitive(p: &PrimitiveSchema) -> Value
pub fn from_primitive(p: &PrimitiveSchema) -> Value
Generates an example value based on a primitive type Schema